@@ -14,17 +14,14 @@ class ImageToolsPlugin : public QQmlExtensionPlugin
 public:
     void registerTypes(const char *uri) override;
 private:
+    QUrl componentUrl(const QString &fileName) const;
 
     QString resolveFileUrl(const QString &filePath) const
     {
 #if defined(Q_OS_ANDROID)
-        return QStringLiteral("qrc:/android_rcc_bundle/qml/org/mauikit/imagetools/") + filePath;
-#else
-#ifdef QUICK_COMPILER
-        return QStringLiteral("qrc:/mauikit/imagetools/") + filePath;
+        return QStringLiteral(":/qt/qml/org/mauikit/imagetools/") + filePath;
 #else
         return baseUrl().toString() + QLatin1Char('/') + filePath;
-#endif
 #endif
     }
 };
